==> PyNFe-1.0.22.tar.gz: PyNFe-1.0.22/pynfe/nfe/manual_600/soap.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
import os
from pynfe.xml_sped.base import *
from ..manual_500 import soap_310

DIRNAME = os.path.dirname(__file__)


class NFeCabecMsg(soap_310.NFeCabecMsg):
    def __init__(self):
        super(NFeCabecMsg, self).__init__()
        self.versaoDados = TagDecimal(nome='versaoDados', codigo='', raiz='//cabecMsg',
                                      tamanho=[1, 4], valor='4.00')


class NFeDadosMsg(soap_310.NFeDadosMsg):
    def __init__(self):
        super(NFeDadosMsg, self).__init__()


class NFeResultMsg(XMLNFe):
    def __init__(self):
        super(NFeResultMsg, self).__init__()
        self.webservice = ''
        self.result = None

    @property
    def xml(self):
        xml = XMLNFe.xml.fget(self)
        xml += '<nfeResultMsg xmlns="http://www.portalfiscal.inf.br/nfe/wsdl/%s>' % self.webservice
        xml += self.result.raw_xml()
        xml += '</nfeResultMsg>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.result.xml = arquivo


class SOAPEnvio(soap_310.SOAPEnvio):
    def __init__(self):
        super(SOAPEnvio, self).__init__()


class SOAPRetorno(soap_310.SOAPRetorno):
    def __init__(self):
        super(SOAPRetorno, self).__init__()
        del self.nfeCabecMsg

    @property
    def xml(self):
        xml = XMLNFe.xml.fget(self)
        xml += ABERTURA
        xml += '<soap:Envelope xmlns:soap="http://www.w3.org/2003/05/soap-envelope">'
        xml += '<soap:Body>'
        xml += '<%sResult xmlns="http://www.portalfiscal.inf.br/nfe/wsdl/%s">' % (
            self.metodo, self.webservice)
        xml += self.resposta.xml
        xml += '</%sResult>' % self.metodo + 'Result>'
        xml += '</soap:Body>'
        xml += '</soap:Envelope>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.resposta.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> PyNFe-5.0.7.tar.gz: PyNFe-5.0.7/pynfe/nfe/manual_600/soap.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
import os
from pynfe.xml_sped.base import *
from pynfe.nfe.manual_500 import soap_310

DIRNAME = os.path.dirname(__file__)


class NFeCabecMsg(soap_310.NFeCabecMsg):
    def __init__(self):
        super(NFeCabecMsg, self).__init__()
        self.versaoDados = TagDecimal(nome='versaoDados', codigo='', raiz='//cabecMsg',
                                      tamanho=[1, 4], valor='4.00')


class NFeDadosMsg(soap_310.NFeDadosMsg):
    def __init__(self):
        super(NFeDadosMsg, self).__init__()


class NFeResultMsg(XMLNFe):
    def __init__(self):
        super(NFeResultMsg, self).__init__()
        self.webservice = ''
        self.result = None

    @property
    def xml(self):
        xml = XMLNFe.xml.fget(self)
        xml += '<nfeResultMsg xmlns="http://www.portalfiscal.inf.br/nfe/wsdl/%s>' % self.webservice
        xml += self.result.raw_xml
        xml += '</nfeResultMsg>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.result.xml = arquivo


class SOAPEnvio(soap_310.SOAPEnvio):
    def __init__(self):
        super(SOAPEnvio, self).__init__()


class SOAPRetorno(soap_310.SOAPRetorno):
    def __init__(self):
        super(SOAPRetorno, self).__init__()
        del self.nfeCabecMsg

    @property
    def xml(self):
        xml = XMLNFe.xml.fget(self)
        xml += ABERTURA
        xml += '<soap:Envelope xmlns:soap="http://www.w3.org/2003/05/soap-envelope">'
        xml += '<soap:Body>'
        xml += '<%sResult xmlns="http://www.portalfiscal.inf.br/nfe/wsdl/%s">' % (
            self.metodo, self.webservice)
        xml += self.resposta.xml
        xml += '</%sResult>' % self.metodo + 'Result>'
        xml += '</soap:Body>'
        xml += '</soap:Envelope>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.resposta.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
